@@ -58,8 +58,8 @@ class Base(ABC):
         return self.value is not sentinel
 
     @property
-    def _mb_comma(self: Base) -> str:
-        return "," if self._has_value else ""
+    def _mb_comma_space(self: Base) -> str:
+        return ", " if self._has_value else ""
 
     @property
     def _mb_paren_value(self: Base) -> str:
