@@ -60,7 +60,7 @@ class Checker(Base):
     def isinstance(self: Checker, x: Union[Type, Tuple[Type, ...]]) -> Checker:  # noqa: A003
         return self._append(IsInstance, x)
 
-    def issubclass(self: Checker, x: Type) -> Checker:  # noqa: A003
+    def issubclass(self: Checker, x: Union[Type, Tuple[Type, ...]]) -> Checker:  # noqa: A003
         return self._append(IsSubClass, x)
 
     # operator
